@@ -1,14 +1,13 @@
 
 import pandas as pd
 import numpy as np
-
 import math
-
 import urllib
 import io
 from PIL import Image
 import os
 import sys
+
 #检索文件
 def searchfile(filename):
     fileroot = ''
@@ -28,7 +27,7 @@ def set_mapboxtoken(mapboxtoken):
     f = open(filepath,mode = 'w')
     f.write(mapboxtoken)
     f.close()
-    print('写入成功')
+    print('Success')
     
 #读取
 def read_mapboxtoken():
@@ -38,7 +37,7 @@ def read_mapboxtoken():
         mapboxtoken = f.readline()
         f.close()
     except:
-        raise Exception('没有找到mapboxtoken，请先设置，详见：https://transbigdata.readthedocs.io/zh_CN/latest/plot_map.html') 
+        raise Exception('Mapboxtoken not found, please use tbd.set_mapboxtoken() to set it first, see: https://transbigdata.readthedocs.io/en/latest/plot_map.html') 
     return mapboxtoken
 
 #写入
@@ -47,7 +46,7 @@ def set_imgsavepath(imgsavepath):
     f = open(filepath,mode = 'w')
     f.write(imgsavepath)
     f.close()
-    print('写入成功')
+    print('Success')
 #读取
 def read_imgsavepath():
     filepath = searchfile('imgsavepath.txt')
@@ -56,7 +55,7 @@ def read_imgsavepath():
         imgsavepath = f.readline()
         f.close()
     except:
-        raise Exception('没有找到地图底图存放路径，请先设置，详见：https://transbigdata.readthedocs.io/zh_CN/latest/plot_map.html') 
+        raise Exception('Map base map storage path not found, please use tbd.set_imgsavepath() to set it first, see: https://transbigdata.readthedocs.io/en/latest/plot_map.html') 
     return imgsavepath
 
 def deg2num(lat_deg, lon_deg, zoom):
@@ -73,9 +72,8 @@ def num2deg(xtile, ytile, zoom):
     lat_deg = math.degrees(lat_rad)
     return (lat_deg, lon_deg)
 
-def getImageCluster( lon_deg,lat_deg, delta_long, delta_lat,zoom,printlog,imgsavepath,style = 4,apikey = '',access_token = '',styleid = 'light'):
+def getImageCluster( lon_deg,lat_deg, delta_long, delta_lat,zoom,printlog,imgsavepath,style = 4,access_token = ''):
     '''
-    apikey - openstreetmap token
     access_token - mapbox token
     '''
     if (style == 1 )|(style == 'streets' ):
@@ -184,13 +182,22 @@ def getImageCluster( lon_deg,lat_deg, delta_long, delta_lat,zoom,printlog,imgsav
     return Cluster
 
     
-def plot_map(plt,bounds,zoom,style=4,printlog = False,apikey = '',styleid = 'light'):
+def plot_map(plt,bounds,zoom = 'auto',style=4,printlog = False):
     '''
-    bounds -- Set your plotting boundary [lon1,lat1,lon2,lat2] (wgs1984)
-    zoom -- The zoom level of the map
-    style -- From 1 to 7 represent different map styles,1-6 is from openstreetmap and 7 is the mapbox
-    styleid -- if style is set as 7(from mapbox), you can change the styleid here, "dark" or "light" or your own style
-    imgsavepath -- Path to save the tile map so that you don't have to download again
+    Plot the basemap
+
+    Parameters
+    -------
+    plt : matplotlib.pyplot
+        Where to plot
+    bounds : List
+        The drawing boundary of the base map, [lon1,lat1,lon2,lat2] (WGS84 coordinate system), where lon1 and lat1 are the coordinates of the lower left corner and lon2 and lat2 are the coordinates of the upper right corner
+    zoom : number
+        The larger the magnification level of the base map, the longer the loading time. Generally, the range for a single city is between 12 and 16
+    printlog : bool
+        Show log
+    style : number
+        The style of map basemap can be 1-10, as follows
     '''
     access_token = read_mapboxtoken()
     imgsavepath = read_imgsavepath()
@@ -203,7 +210,10 @@ def plot_map(plt,bounds,zoom,style=4,printlog = False,apikey = '',styleid = 'lig
     lat1 =  bounds[1]
     lon2 =  bounds[2]
     lat2 =  bounds[3]
-    a = getImageCluster(lon1, lat1, lon2-lon1,  lat2-lat1, zoom,style = style,printlog = printlog,imgsavepath = imgsavepath,apikey = apikey,access_token = access_token, styleid = styleid)
+    if zoom == 'auto':
+        zoom = 11-np.log(lon2-lon1)/np.log(2)
+    zoom = min(18,int(zoom+0.5))
+    a = getImageCluster(lon1, lat1, lon2-lon1,  lat2-lat1, zoom,style = style,printlog = printlog,imgsavepath = imgsavepath,access_token = access_token)
     x1, y1 =deg2num(lat1, lon1, zoom)
     x2, y2 =deg2num(lat2, lon2, zoom)
     x1,y1 = num2deg(x1, y1+1, zoom)
@@ -212,7 +222,26 @@ def plot_map(plt,bounds,zoom,style=4,printlog = False,apikey = '',styleid = 'lig
 
 
 def plotscale(ax,bounds,textcolor = 'k',textsize = 8,compasssize = 1,accuracy = 'auto',rect=[0.1,0.1],unit = "KM",style = 1,**kwargs):
-    
+    '''
+    Add compass and scale for a map
+
+    Parameters
+    -------
+    bounds : List
+        The drawing boundary of the base map, [lon1,lat1,lon2,lat2] (WGS84 coordinate system), where lon1 and lat1 are the coordinates of the lower left corner and lon2 and lat2 are the coordinates of the upper right corner
+    textsize : number
+        size of the text
+    compasssize : number
+        size of the compass
+    accuracy : number
+        Length of scale bar (m)
+    unit : str
+        ‘KM’,’km’,’M’,’m’, the scale units
+    style : number
+        1 or 2, the style of the scale
+    rect : List
+        The approximate position of the scale bar in the figure, such as [0.9,0.9], is in the upper right corner
+    '''
     #栅格化代码
     import math
 
